Brian2GeNN documentation
=========================

Contents:

.. toctree::
   :maxdepth: 2
   :titlesonly:

   introduction/index
   introduction/exclusions
   introduction/preferences
   technical/how_it_works
   technical/release
   
.. toctree::
   :maxdepth: 1
   :titlesonly:
   
   Reference documentation <reference/brian2genn>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
